@@ -5,7 +5,7 @@ use warnings;
 
 use Data::Dumper;
 use JSON;
-use List::Util qw(pairs);
+use List::Util   qw(pairs);
 use Scalar::Util qw(reftype);
 use Text::ASCIITable;
 
@@ -13,7 +13,7 @@ use parent qw(Exporter);
 
 our @EXPORT = qw(easy_table);  ## no critic (ProhibitAutomaticExportation)
 
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 
 ########################################################################
 {
@@ -57,7 +57,7 @@ sub easy_table {
 
   my @columns;
 
-  if ( $options{columns} ) {
+  if ( $options{columns} && !$options{index} ) {
     die "'columns' must be an ARRAY\n"
       if !is_array $options{columns};
 
@@ -72,6 +72,18 @@ sub easy_table {
 
     @columns = map { $_->[0] } pairs @{ $options{rows} };
   }
+  elsif ( $options{index} ) {
+
+    @columns = map { $_->[0] } pairs @{ $options{index} };
+
+    my %index = @{ $options{index} };
+
+    $options{rows} = [
+      map {
+        ( $_ => sub { return shift->{ $index{ shift() } } } )
+      } @columns
+    ];
+  }
   else {
     @columns = keys %{ $options{data}->[0] };
   }
@@ -199,12 +211,7 @@ Text::ASCIITable::EasyTable - create ASCII tables from an array of hashes
  ];
 
  # easy
- my %index = ( ImageId => 'col1', Name => 'col2' );
-
- my $rows = [
-   ImageId => sub { shift->{ $index{ shift() } } },
-   Name    => sub { shift->{ $index{ shift() } } },
- ];
+ my @index = ( ImageId => 'col1', Name => 'col2' );
  
  print easy_table(
    data          => $data,
@@ -222,7 +229,6 @@ Text::ASCIITable::EasyTable - create ASCII tables from an array of hashes
  # easiest 
  print easy_table( data => $data );
 
-
 =head1 DESCRIPTION
 
 L<Text::ASCIITable> is one of my favorite modules when I'm writing
@@ -245,8 +251,9 @@ also allow you to set the order of the data to be displayed in the table.
 
 =item * Sort rows by individual columns in the hashes
 
-=item * Output JSON instead of a tableInstead of rendering a table, C<easy_table> can apply the same type of
-transformations to arrays of hashes and subsequently output JSON.
+=item * Output JSON instead of a tableInstead of rendering a table,
+C<easy_table> can apply the same type of transformations to arrays of
+hashes and subsequently output JSON.
 
 =back
 
@@ -256,6 +263,11 @@ Exports one method C<easy_table>.
 
 =head2 easy_table
 
+ easy_table(key => value, ...)
+
+Returns a C<Text::ASCIITable> object that you can print. Accepts a list
+of key/value pairs described below.
+
 =over 5
 
 =item rows
@@ -297,8 +309,39 @@ extract data from the hash for each row and the labels for each column.
 
 Array of hashes that contain the data for the table.
 
+=item index
+
+An array (not a hash) of key/value pairs that define the column name (key)
+for a key (value) in a hash.
+
+Suppose your data looks like this:
+
+ [
+   { Subnet    => "subnet-12345678",
+     VpcId     => "vpc-12345678",
+     CidrBlock => "10.1.4.0/24"
+   }
+   ...
+ ]
+
+ print easy_table(
+   table_options => { headingText => 'Subnets' },
+   data          => $data,
+   index         => [ Subnet => 'Subnet', VPC => 'VpcId', IP => 'CidrBlock' ]
+ );
+
+ .----------------------------------------------.
+ |                    Subnets                   |
+ +-----------------+--------------+-------------+
+ | Subnet          | VPC          | IP          |
+ +-----------------+--------------+-------------+
+ | subnet-12345678 | vpc-12345678 | 10.1.4.0/24 |
+ '-----------------+--------------+-------------'
+
 =item json
 
+Boolean that determines if a table or a JSON object should be returned.
+
 Instead of a table, return a JSON representation. The point here, is
 to use the transformation capabilities but rather than rendering a
 table, output JSON. Using this option you can transform the keys or
@@ -341,13 +384,6 @@ to transform the column names and column values in a table.
     }
  ]
 
-=over 5
-
-=item * I<C<easy_table()> is meant to be used on small data sets and may not
-be efficient when larger data sets are used.>
-
-=back
-
 =item max_rows
 
 Maximum number of rows to render.
@@ -385,6 +421,15 @@ the C<columns> or C<rows> parameters. If you just want to see some
 data and don't care about order, you can just send the C<data>
 parameter and the method will more or less DWIM.>
 
+=head1 CAVEATS
+
+=over 5
+
+=item * I<C<easy_table()> is meant to be used on small data sets and may not
+be efficient when larger data sets are used.>
+
+=back
+
 =head1 SEE ALSO
 
 L<Text::ASCIITable>, L<Term::ANSIColor>
